@@ -2,7 +2,7 @@
 """
 @Author: ChenCheng
 @Date: 2022-03-18 10:12:12
-@LastEditTime: 2022-07-21 10:50:43
+@LastEditTime: 2022-07-22 10:38:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -48,7 +48,7 @@ class ResetLaunchGoodsHandler(SevenBaseHandler):
         """
         app_id = self.get_param("app_id")
         act_id = int(self.get_param("act_id", 0))
-        ActInfoModel(context=self).update_table("is_launch=0", "app_id=%s and id=%s", params=[app_id, act_id])
+        ActInfoModel(context=self).update_table("is_throw=0", "app_id=%s and id=%s", params=[app_id, act_id])
         LaunchGoodsModel(context=self).del_entity("app_id=%s and act_id=%s", params=[app_id, act_id])
         return self.reponse_json_success()
 
@@ -73,7 +73,7 @@ class InitLaunchGoodsCallBackHandler(SevenBaseHandler):
         call_back_info = self.get_param("call_back_info")
 
         try:
-            ActInfoModel(context=self).update_table("is_launch=1", "id=%s", params=act_id)
+            ActInfoModel(context=self).update_table("is_throw=1", "id=%s", params=act_id)
             if close_goods_id != "":
                 close_goods_id_list = list(set(close_goods_id.split(",")))
                 close_goods_id_str_list = ','.join(["'%s'" % str(item) for item in close_goods_id_list])
@@ -342,7 +342,7 @@ class GetLaunchPlanStatusHandler(TopBaseHandler):
 
         if not launch_plan:
             if act_info:
-                if act_info.is_launch == 1:
+                if act_info.is_throw == 1:
                     return self.reponse_json_success(launch_status)
                 else:
                     return self.reponse_json_success(0)
@@ -357,7 +357,7 @@ class GetLaunchPlanStatusHandler(TopBaseHandler):
         if tb_launch_status == 0:
             tb_launch_status = 1
 
-        if tb_launch_status == 2 and act_info.is_launch == 0:
+        if tb_launch_status == 2 and act_info.is_throw == 0:
             tb_launch_status = 0
         launch_status = tb_launch_status
         return self.reponse_json_success(launch_status)
